@@ -1,6 +1,8 @@
 import asyncio
+import json
 import logging
 import os
+import pprint
 import subprocess
 import sys
 from collections import defaultdict
@@ -8,6 +10,7 @@ from datetime import datetime
 
 import aiohttp
 import dyne.org.funtoo.powerbus as powerbus
+from bson.json_util import CANONICAL_JSON_OPTIONS, loads
 from dbus_next import Message, InterfaceNotFoundError, BusType
 from dbus_next.aio import MessageBus
 
@@ -141,6 +144,21 @@ async def prepare_for_sleep():
 	await lock_screensaver()
 
 
+class FuntooStatusClient(object):
+	def __init__(self):
+		self.ws = None
+
+	async def connect(self):
+		try:
+			conn = aiohttp.UnixConnector(path=powerbus.socket.POWERBUS_PATH)
+			async with aiohttp.ClientSession(connector=conn) as session:
+				async with session.get("http://socket/status") as resp:
+					json_dict = json.loads(await resp.text())
+					print(json.dumps(json_dict, indent=4))
+		except (aiohttp.ClientConnectionError, ConnectionResetError) as e:
+			logging.error("Connection error.")
+
+
 class FuntooIdleClient(object):
 	def __init__(self):
 		self.last_msg = datetime.utcnow()
@@ -213,5 +231,5 @@ class FuntooIdleClient(object):
 			DISPLAY=os.environ["DISPLAY"] if "DISPLAY" in os.environ else None,
 			inhibitors=await get_session_inhibitors(),
 		)
-		logging.warning("idle =", out_msg.idle)
+		logging.warning("idle = {out_msg.idle}")
 		await out_msg.send(self.ws)
