@@ -11,6 +11,7 @@ from enum import Enum
 import aiohttp
 import colorama
 from aiohttp import web
+from bson.json_util import CANONICAL_JSON_OPTIONS, dumps
 from dbus_next import Message, BusType
 from dbus_next.aio import MessageBus
 
@@ -218,6 +219,9 @@ class PowerBusDaemon(object):
 		This method starts the server as a background Task, and returns.
 		"""
 
+		async def status_handler(request):
+			return web.Response(text=dumps(await self.status_json(), json_options=CANONICAL_JSON_OPTIONS))
+
 		async def websocket_handler(request):
 			logging.warning("Got connection!")
 			ws = web.WebSocketResponse()
@@ -254,7 +258,7 @@ class PowerBusDaemon(object):
 			raise PermissionError("Unable to write PID file at /run/funtoo/powerbus.pid.")
 
 		self.app = web.Application()
-		self.app.add_routes([web.get("/ws", websocket_handler)])
+		self.app.add_routes([web.get("/ws", websocket_handler), web.get("/status", status_handler)])
 		self.runner = web.AppRunner(self.app)
 		await self.runner.setup()
 		os.umask(0o000)
@@ -561,6 +565,36 @@ class PowerBusDaemon(object):
 			await asyncio.sleep(0.25)
 			self.go_to_sleep()
 
+	async def status_json(self):
+		out_json = {}
+		sleep, reason = await self.will_consider_natural_sleep()
+		out_json["natural_sleep"] = sleep
+		out_json["natural_sleep_reason"] = reason
+		out_json["has_lid"] = self.has_lid
+		out_json["times"] = {
+			"daemon_start": self.daemon_start,
+			"last_zero": self.last_zero,
+			"lid_last_closed": LID_LAST_CLOSED,
+			"lid_last_opened": LID_LAST_OPENED,
+			"last_maybe_accel": self.last_maybe_accelerated_sleep,
+			"last_accel_sleep": self.last_accelerated_sleep,
+			"last_sleep": None if self.last_sleep_attempt == self.daemon_start else self.last_sleep_attempt,
+		}
+		for key, val in out_json["times"].items():
+			if val is not None:
+				out_json["times"][key] = str(val)
+		out_json["state"] = str(self.state)
+		out_json["clients"] = []
+		for ckey, datums in self.clients.items():
+			out_json["clients"].append((client_key_to_str(ckey), datums))
+		out_json["on_ac"] = on_ac_power()
+		out_json["ignore_inhibit"] = powerbus.model.ignore_inhibit
+		out_json["sleep_inhibit"] = await sleep_inhibited()
+		session_inhibit, inhibitors = self.session_sleep_inhibited()
+		out_json["session_inhibit"] = session_inhibit
+		out_json["session_inhibitors"] = inhibitors
+		return out_json
+
 	async def status_display(self):
 		while True:
 			print(colorama.ansi.clear_screen())
